% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/simulation_report.R
\name{evaluation_report}
\alias{evaluation_report}
\title{Compute evaluation report for TMB/DESeq2 analysis}
\usage{
evaluation_report(
  list_tmb,
  dds,
  mock_obj,
  coeff_threshold,
  alt_hypothesis,
  alpha_risk = 0.05,
  palette_color = c(DESeq2 = "#500472", HTRfit = "#79cbb8"),
  palette_shape = c(DESeq2 = 17, HTRfit = 19),
  skip_eval_intercept = TRUE,
  ...
)
}
\arguments{
\item{list_tmb}{TMB results from analysis.}

\item{dds}{DESeq2 results from differential gene expression analysis.}

\item{mock_obj}{Mock object that represents the distribution of measurements corresponding
to mock samples.}

\item{coeff_threshold}{A non-negative value which specifies a ln(fold change) threshold. The Threshold  is used for the Wald test to determine whether the  coefficient (β) is significant or not, depending on \code{alt_hypothesis} parameter. Default is 0, ln(FC = 1).}

\item{alt_hypothesis}{Alternative hypothesis for the Wald test (default is "greaterAbs").
Possible choice:
"greater"
\itemize{
\item β > coeff_threshold,
"less"
\item β < −coeff_threshold,
or two-tailed alternative:
"greaterAbs"
\item |β| > coeff_threshold
}}

\item{alpha_risk}{parameter that sets the threshold for alpha risk level while testing coefficient (β). Default: 0.05.}

\item{palette_color}{Optional parameter that sets the color palette for plots.Default : c(DESeq2 = "#500472", HTRfit ="#79cbb8").}

\item{palette_shape}{Optional parameter that sets the point shape for plots.Default : c(DESeq2 = 17, HTRfit = 19).}

\item{skip_eval_intercept}{indicate whether to calculate precision-recall and ROC metrics for the intercept (default TRUE).}

\item{...}{Additional parameters to be passed to aesthetics \code{get_pr_curve} and \code{get_roc_curve}.}
}
\value{
A list containing the following components:
\item{identity}{A list containing model parameters and dispersion data.}
\item{precision_recall}{A PR curve object generated from TMB and DESeq2 results.}
\item{roc}{A ROC curve object generated from TMB and DESeq2 results.}
\item{counts}{A counts plot generated from mock object.}
\item{performances}{A summary of the performances obtained.}
}
\description{
This function computes an evaluation report for TMB/DESeq2 analysis using several graphical
summaries like precision-recall (PR) curve, Receiver operating characteristic (ROC) curve
and others. It takes as input several parameters like TMB results (\code{l_tmb}), DESeq2
result (\code{dds}), mock object (\code{mock_obj}), coefficient threshold (\code{coeff_threshold}) and
alternative hypothesis (\code{alt_hypothesis}).
}
