# WARNING - Generated by {fusen} from /dev/flat_full.Rmd: do not edit by hand


test_that("Test for subsetFixEffectInferred function", {
  # Prepare the test data
  input_var_list <- init_variable(name = "varA", mu = c(1,2,3), level = 3) %>%
                    init_variable(name = "varB", mu = c(2,-6), level = 2) %>%
                    add_interaction(between_var = c("varA", "varB"), mu = 1, sd = 3)

  mock_data <- mock_rnaseq(input_var_list, 10, 2, 2)
  getData2computeActualFixEffect(mock_data$groundTruth$effect)
  data2fit <- prepareData2fit(countMatrix = mock_data$counts, metadata = mock_data$metadata, normalization = F)

  # Fit data
  resFit <- fitModelParallel(formula = kij ~ varA + varB + varA:varB,
                             data = data2fit, group_by = "geneID",
                             family = glmmTMB::nbinom2(link = "log"), n.cores = 1)
  tidy_tmb <- tidy_tmb(resFit)

  # Test the subsetFixEffectInferred function
  result <- subsetFixEffectInferred(tidy_tmb)
  # Define expected output
  expected_nonInteraction <- c("varA2", "varA3", "varB2")
  expected_interaction <- c("varA2:varB2", "varA3:varB2")

  # Compare the output with the expected values
  expect_equal(result$fixed_term$nonInteraction, expected_nonInteraction)
  expect_equal(result$fixed_term$interaction, expected_interaction)
})


# Tests for averageByGroup
test_that("averageByGroup returns correct average values", {
  # Create a sample data frame
  data <- data.frame(
    Group1 = rep(c("A", "B", "C", "D"), each = 2),
    Group2 = rep(c("X", "Y"), times = 4),
    Value = 1:8
  )
  
  # Calculate average values by group
  result <- averageByGroup(data, column = "Value", group_by = c("Group1", "Group2"))
  
  # Check the output
  expect_equal(nrow(result), 8)  # Number of rows
  expect_equal(colnames(result), c("logQij_mean","Group1", "Group2" ))  # Column names
  expect_equal(result$logQij_mean, c(1, 3,5, 7, 2, 4, 6, 8))  # Average values
})



# Tests for findAttribute
test_that("findAttribute returns the correct attribute", {
  # Create a sample list
  my_list <- list(
    color = c("red", "blue", "green"),
    size = c("small", "medium", "large"),
    shape = c("circle", "square", "triangle")
  )
  
  # Find attributes
  attr1 <- findAttribute("medium", my_list)
  attr2 <- findAttribute("rectangle", my_list)
  
  # Check the output
  expect_equal(attr1, "size")  # Attribute containing "medium"
  expect_equal(attr2, NULL)  # Attribute containing "rectangle"
})

# Tests for getActualIntercept
test_that("getActualIntercept returns the correct intercept dataframe", {
  # Create a sample data frame
  data <- data.frame(
    Category1 = c("A", "B", "A", "B"),
    Category2 = c("X", "Y", "X", "Z"),
    logQij_mean = 1:4
  )
  data[, c("Category1", "Category2")] <- lapply(data[, c("Category1", "Category2")], as.factor )
  
  l_fixEffDataActual= list(categorical_vars = c("Category1", "Category2"), data = data)
  # Get the intercept dataframe
  result <- getActualIntercept(l_fixEffDataActual)
  
  # Check the output
  expect_equal(nrow(result), 2)  # Number of rows
  expect_equal(unique(result$term), "(Intercept)")  # Term column
  expect_equal(result$actual, c(1, 3))  # Actual column
})





# Test subsetByTermLabel with single categorical variable
test_that("subsetByTermLabel with single categorical variable", {
  my_data <- list(color = c("red", "blue", "green", "red"),
                        size = c("small", "medium", "large", "medium"),
                        shape = c("circle", "square", "triangle", "circle"))
  my_data <- expand.grid(my_data)
  my_data[] <- lapply(my_data, as.factor)

  subset_data <- subsetByTermLabel(my_data, categorical_vars = "size", term_label = "medium")
  expected_data <- my_data[my_data$size == "medium", ]
  expected_data$term <- "medium"
  
  expect_equal(subset_data, expected_data)
})

# Test subsetByTermLabel with single term label in multiple categorical variables
test_that("subsetByTermLabel with single term label in multiple categorical variables", {
   my_data <- list(color = c("red", "blue", "green", "red"),
                        size = c("small", "medium", "large", "medium"),
                        shape = c("circle", "square", "triangle", "circle"))
  my_data <- expand.grid(my_data)
  my_data[] <- lapply(my_data, as.factor)

  subset_data <- subsetByTermLabel(data = my_data, categorical_vars = c("color", "shape"), term_label = "circle")
  expected_data <- my_data[my_data$shape == "circle" & my_data$color == "red" , ]
  expected_data$term <- "circle"

  expect_equal(subset_data, expected_data)
})

# Test subsetByTermLabel with non-existent term label expect error
test_that("subsetByTermLabel with non-existent term label", {
   my_data <- list(color = c("red", "blue", "green", "red"),
                        size = c("small", "medium", "large", "medium"),
                        shape = c("circle", "square", "triangle", "circle"))
  my_data <- expand.grid(my_data)
  my_data[] <- lapply(my_data, as.factor)

  expect_error(subsetByTermLabel(data = my_data, categorical_vars = "size", term_label = "extra-large"))
})



# Test getActualMainFixEff
test_that("getActualMainFixEff", {
  input_var_list <- init_variable() 
  mock_data <- mock_rnaseq(input_var_list, 2, 2, 2)
  data2fit <- prepareData2fit(mock_data$counts, mock_data$metadata)
  inference <- fitModelParallel(kij ~ myVariable , 
                                  group_by = "geneID", data2fit, n.cores = 1)
  tidy_inference <- tidy_tmb(inference)
  tidy_fix <- subsetFixEffectInferred(tidy_inference)
  fixEff_dataActual <- getData2computeActualFixEffect(mock_data$groundTruth$effects)
  actual_intercept <- getActualIntercept(fixEff_dataActual)
  ## -- main = non interaction
  actual_mainFixEff <- getActualMainFixEff(tidy_fix$fixed_term$nonInteraction,
                    fixEff_dataActual, actual_intercept)
  
  expected_actual <- data.frame(geneID = c("gene1", "gene2"),
                                term = c("myVariable2", "myVariable2"),
                                actual = c(1, 1),
                                description = "myVariable")
  rownames(actual_mainFixEff) <- NULL
  rownames(actual_mainFixEff) <- NULL
  expect_equal(actual_mainFixEff, expected_actual)
})



test_that("getData2computeActualFixEffect return correct output",{
  # Prepare the test data
  input_var_list <- init_variable() 
  mock_data <- mock_rnaseq(input_var_list, 2, 2, 2)
  data2fit <- prepareData2fit(mock_data$counts, mock_data$metadata)
  inference <- fitModelParallel(kij ~ myVariable, group_by = "geneID", data2fit, n.cores = 1)
  tidy_inference <- tidy_tmb(inference)
  tidy_fix <- subsetFixEffectInferred(tidy_inference)

  # Call the function to test
  fixEff_dataActual <- getData2computeActualFixEffect(mock_data$groundTruth$effects)

  # Define expected output
  expected_data <- data.frame(logQij_mean = c(2,2,3,3), geneID = c("gene1", "gene2", "gene1", "gene2"), label_myVariable = factor(c("myVariable1", "myVariable1", "myVariable2", "myVariable2")))
  expected_categorical_vars <- "label_myVariable"
  # Compare the output with the expected values
  expect_equal(fixEff_dataActual$data, expected_data)
  expect_equal(fixEff_dataActual$categorical_vars, expected_categorical_vars)
})


test_that("generateActualForMainFixEff returns correct values for main fixed effect term", {
  # Prepare the test data
  input_var_list <- init_variable() 
  mock_data <- mock_rnaseq(input_var_list, 2, 2, 2)
  data2fit <- prepareData2fit(mock_data$counts, mock_data$metadata)
  fixEff_dataActual <- getData2computeActualFixEffect(mock_data$groundTruth$effects)
  actual_intercept <- getActualIntercept(fixEff_dataActual)
  df_term <- generateActualForMainFixEff("myVariable2", actual_intercept, fixEff_dataActual$data, fixEff_dataActual$categorical_vars)

  # Define expected output
  expected <- data.frame(
    geneID = c("gene1", "gene2"),
    label_myVariable = factor(c("myVariable2", "myVariable2"), levels = c("myVariable1", "myVariable2")),
    term = c("myVariable2", "myVariable2"),
    actual = c(1, 1),
    description = c("myVariable", "myVariable")
  )
  rownames(df_term) <- NULL
  rownames(expected) <- NULL
  # Compare the output with the expected values
  expect_equal(df_term, expected)
})

