# WARNING - Generated by {fusen} from /dev/flat_full.Rmd: do not edit by hand



# Test case 1: Testing with a sample data frame
test_that("Generating a formatted table works correctly", {
  sample_data <- data.frame(
    Name = c("Alice", "Bob", "Charlie"),
    Age = c(25, 30, 28)
  )
  
  table_grob <- getGrobTable(sample_data)
  
  expect_s3_class(table_grob, "gtable")
})

# Test case 4: Testing with non-numeric values
test_that("Handling non-numeric values in the data frame", {
  non_numeric_data <- data.frame(
    Name = c("Alice", "Bob", "Charlie"),
    Age = c(25, "N/A", 28)
)
  
  table_grob <- getGrobTable(non_numeric_data)
  
  expect_s3_class(table_grob, "gtable")
})




# Test get_eval_data_from_ltmb
test_that("get_eval_data_from_ltmb returns correct output", {
  
  input_var_list <- init_variable( name = "varA", mu = 3, sd = 2, level = 3) 
  
  ## -- Required parameters
  N_GENES = 3
  MIN_REPLICATES = 3
  MAX_REPLICATES = 3
  ########################
  
  ## -- simulate RNAseq data based on input_var_list, minimum input required
  ## -- number of replicate randomly defined between MIN_REP and MAX_REP
  mock_data <- mock_rnaseq(input_var_list, N_GENES,
                         min_replicates  = MIN_REPLICATES,
                         max_replicates = MAX_REPLICATES)
  ## -- data from simulation 
  count_matrix <- mock_data$counts
  metaData <- mock_data$metadata
  ##############################
  ## -- convert counts matrix and samples metadatas in a data frame for fitting
  data2fit = prepareData2fit(countMatrix = count_matrix,
                           metadata =  metaData,
                           normalization = F)
  l_tmb <- fitModelParallel(formula = kij ~ varA  ,
                          data = data2fit,
                          group_by = "geneID",
                          family = glmmTMB::nbinom2(link = "log"),
                          n.cores = 1)
 
  eval_data_ltmb <- get_eval_data_from_ltmb(l_tmb, mock_data, 0.27, 'greater')
  expect_is(eval_data_ltmb, "list")
  expect_named(eval_data_ltmb, c("modelparams", "modeldispersion"))
})

# Test get_eval_data_from_dds
test_that("get_eval_data_from_dds returns correct output", {
  
  input_var_list <- init_variable( name = "varA", mu = 3, sd = 2, level = 3) 
  
  ## -- Required parameters
  N_GENES = 100
  MIN_REPLICATES = 3
  MAX_REPLICATES = 3
  ########################
  
  ## -- simulate RNAseq data based on input_var_list, minimum input required
  ## -- number of replicate randomly defined between MIN_REP and MAX_REP
  mock_data <- mock_rnaseq(input_var_list, N_GENES,
                         min_replicates  = MIN_REPLICATES,
                         max_replicates = MAX_REPLICATES)
  ## -- data from simulation 
  count_matrix <- mock_data$counts
  metaData <- mock_data$metadata
  ##############################
  
  dds <- DESeq2::DESeqDataSetFromMatrix(count_matrix, colData = metaData, ~ varA )
  dds <- DESeq2::DESeq(dds)
  
  eval_data_dds <- get_eval_data_from_dds(dds, mock_data, 0.27, "greater")
  
  expect_is(eval_data_dds, "list")
  expect_named(eval_data_dds, c("modelparams", "modeldispersion"))
})

# Test rbind_evaldata_tmb_dds
test_that("rbind_evaldata_tmb_dds returns correct output", {
  
  input_var_list <- init_variable( name = "varA", mu = 3, sd = 2, level = 3) 
  
  ## -- Required parameters
  N_GENES = 15
  MIN_REPLICATES = 3
  MAX_REPLICATES = 3
  ########################
  
  ## -- simulate RNAseq data based on input_var_list, minimum input required
  ## -- number of replicate randomly defined between MIN_REP and MAX_REP
  mock_data <- mock_rnaseq(input_var_list, N_GENES,
                         min_replicates  = MIN_REPLICATES,
                         max_replicates = MAX_REPLICATES)
  ## -- data from simulation 
  count_matrix <- mock_data$counts
  metaData <- mock_data$metadata
  ##############################
  ## -- convert counts matrix and samples metadatas in a data frame for fitting
  data2fit = prepareData2fit(countMatrix = count_matrix,
                           metadata =  metaData,
                           normalization = F)
  l_tmb <- fitModelParallel(formula = kij ~ varA  ,
                          data = data2fit,
                          group_by = "geneID",
                          family = glmmTMB::nbinom2(link = "log"),
                          n.cores = 1)
  dds <- DESeq2::DESeqDataSetFromMatrix(count_matrix, colData = metaData, ~ varA )
  dds <- DESeq2::DESeq(dds)
  
  eval_data_dds <- get_eval_data_from_dds(dds, mock_data, 0.27, "greater")
  eval_data_ltmb <- get_eval_data_from_ltmb(l_tmb, mock_data, 0.27, 'greater')
  
  combined_eval_data <- rbind_evaldata_tmb_dds(eval_data_ltmb, eval_data_dds)
  
  expect_is(combined_eval_data, "list")
  expect_named(combined_eval_data, c("modelparams", "modeldispersion"))
})

# Test rbind_model_params_and_dispersion
test_that("rbind_model_params_and_dispersion returns correct output", {
  
  input_var_list <- init_variable( name = "varA", mu = 3, sd = 2, level = 3) 
  
  ## -- Required parameters
  N_GENES = 100
  MIN_REPLICATES = 3
  MAX_REPLICATES = 3
  ########################
  
  ## -- simulate RNAseq data based on input_var_list, minimum input required
  ## -- number of replicate randomly defined between MIN_REP and MAX_REP
  mock_data <- mock_rnaseq(input_var_list, N_GENES,
                         min_replicates  = MIN_REPLICATES,
                         max_replicates = MAX_REPLICATES)
  ## -- data from simulation 
  count_matrix <- mock_data$counts
  metaData <- mock_data$metadata
  ##############################

  dds <- DESeq2::DESeqDataSetFromMatrix(count_matrix, colData = metaData, ~ varA )
  dds <- DESeq2::DESeq(dds)
  
  
  eval_data <- get_eval_data_from_dds(dds, mock_data, 0.27, "greater")
  
  combined_data <- rbind_model_params_and_dispersion(eval_data)
  
  expect_is(combined_data, "data.frame")
})

# Test get_eval_data
test_that("get_eval_data returns correct output", {
  
  input_var_list <- init_variable( name = "varA", mu = 3, sd = 2, level = 3) 
  
  ## -- Required parameters
  N_GENES = 50
  MIN_REPLICATES = 3
  MAX_REPLICATES = 3
  ########################
  
  ## -- simulate RNAseq data based on input_var_list, minimum input required
  ## -- number of replicate randomly defined between MIN_REP and MAX_REP
  mock_data <- mock_rnaseq(input_var_list, N_GENES,
                         min_replicates  = MIN_REPLICATES,
                         max_replicates = MAX_REPLICATES)
  ## -- data from simulation 
  count_matrix <- mock_data$counts
  metaData <- mock_data$metadata
  ##############################
  ## -- convert counts matrix and samples metadatas in a data frame for fitting
  data2fit = prepareData2fit(countMatrix = count_matrix,
                           metadata =  metaData,
                           normalization = F)
  l_tmb <- fitModelParallel(formula = kij ~ varA  ,
                          data = data2fit,
                          group_by = "geneID",
                          family = glmmTMB::nbinom2(link = "log"),
                          n.cores = 1)
  dds <- DESeq2::DESeqDataSetFromMatrix(count_matrix, colData = metaData, ~ varA )
  dds <- DESeq2::DESeq(dds)
  
  
  eval_data <- get_eval_data(l_tmb, dds, mock_data, 0.27, "greater")
  
  expect_is(eval_data, "list")
  expect_named(eval_data, c("modelparams", "modeldispersion"))
  expect_equal(unique(eval_data$modelparams$from), c("HTRfit", "DESeq2"))
  
  
  ## -- dds == NULL
  eval_data <- get_eval_data(l_tmb, NULL, mock_data, 0.27, "greater")
  expect_is(eval_data, "list")
  expect_named(eval_data, c("modelparams", "modeldispersion"))
  expect_equal(unique(eval_data$modelparams$from), c("HTRfit"))
  
  
    ## -- l_tmb == NULL
  eval_data <- get_eval_data(NULL, dds, mock_data, 0.27, "greater")
  expect_is(eval_data, "list")
  expect_named(eval_data, c("modelparams", "modeldispersion"))
  expect_equal(unique(eval_data$modelparams$from), c("DESeq2"))

})



